# full parallel build seems to fail in Qt, so limite to -j4 level:
%global _smp_ncpus_max 4

%define bname		Dogecoin
%define consensus_major	0
%define libconsensus	%mklibname %{name}consensus %{consensus_major}
%define consensus_devel	%mklibname %{name}consensus -d

Summary:	%{bname} payment network
Name:		dogecoin
Version:	1.14.7
Release:	%mkrel 1
License:	MIT
Group:		Office/Finance
Url:		https://dogecoin.com/
Source0:	https://github.com/dogecoin/dogecoin/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:		dogecoin-1.14.2-rename-bitcoinconsensus-to-dogecoinconsensus.patch
Patch2:		dogecoin-gcc11.patch
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	boost-devel
# db5.1 recommended for wallet portability, but 5.3 works:
BuildRequires:	db-devel >= 5.3.0
BuildRequires:	miniupnpc-devel
BuildRequires:	pkgconfig(libevent)
BuildRequires:	pkgconfig(libqrencode)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	protobuf-compiler
BuildRequires:	pkgconfig(openssl)

%description
%{bname} is an innovative payment network and a new kind of money.

%package -n %{name}d
Summary:	%{bname} command line client
Group:		Office/Finance

%description -n %{name}d
%{name}d is the original %{bname} command line client.

%package qt
Summary:	%{bname} graphical Qt client
Group:		Office/Finance
Requires:	%{libconsensus} = %{version}

%description qt
%{bname}-Qt is the original %{bname} graphical client.

%package -n %{libconsensus}
Summary:	Shared libs for %{name}consensus
Group:		System/Libraries

%description -n %{libconsensus}
Shared libs for %{name}consensus.

%package -n %{consensus_devel}
Summary:	Development files for %{name}consensus
Group:		Development/C
Requires:	%{libconsensus} = %{version}
Provides:	%{name}-devel = %{version}

%description -n %{consensus_devel}
This package contains development files for the %{name}consensus
library.

%prep
%autosetup -p1

# At least C++14 is required by Boost
sed -i -e '/AX_CXX_COMPILE_STDCXX/s/\[1[0-3]\]/\[14\]/' configure.ac

%build
./autogen.sh
export CPPFLAGS="-I%{_includedir}/db53"
%configure \
    --disable-static \
    --disable-silent-rules \
    --disable-tests \
    --with-incompatible-bdb \
    --with-gui=qt5

%make_build

%install
%make_install

install -d %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -m644 share/pixmaps/%{name}256.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

install -d %{buildroot}%{_datadir}/applications
install -m644 contrib/debian/%{name}-qt.desktop %{buildroot}%{_datadir}/applications
perl -pi -e 's/dogecoin128/dogecoin/g' %{buildroot}%{_datadir}/applications/%{name}-qt.desktop

install -d %{buildroot}%{_datadir}/kservices5
install -m644 contrib/debian/%{name}-qt.protocol %{buildroot}%{_datadir}/kservices5

install -d %{buildroot}%{_datadir}/bash-completion/completions
install -m644 contrib/dogecoind.bash-completion %{buildroot}%{_datadir}/bash-completion/completions/%{name}d

find %{buildroot} -name '*.la' -delete

%files -n %{name}d
%{_bindir}/%{name}d
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-tx
%{_bindir}/bench_%{name}
%{_mandir}/man1/%{name}d.1%{_extension}
%{_mandir}/man1/%{name}-cli.1%{_extension}
%{_mandir}/man1/%{name}-tx.1%{_extension}
%{_datadir}/bash-completion/completions/%{name}d
%doc contrib/qos
%doc contrib/linearize


%files qt
%{_bindir}/%{name}-qt
%{_mandir}/man1/%{name}-qt.1%{_extension}
%{_iconsdir}/hicolor/*/apps/%{name}.svg
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/kservices5/%{name}-qt.protocol


%files -n %{libconsensus}
%{_libdir}/lib%{name}consensus.so.%{consensus_major}{,.*}


%files -n %{consensus_devel}
%{_includedir}/%{name}consensus.h
%{_libdir}/lib%{name}consensus.so
%{_libdir}/pkgconfig/lib%{name}consensus.pc



%changelog
* Fri May 10 2024 daviddavid <daviddavid> 1.14.7-1.mga10
+ Revision: 2063282
- new version: 1.14.7

* Tue Jan 16 2024 wally <wally> 1.14.6-4.mga10
+ Revision: 2031571
- fix build with gcc >= 11
- build with -std=c++14 as required by boost
- rebuild for boost 1.84.0

* Sun Dec 25 2022 wally <wally> 1.14.6-3.mga9
+ Revision: 1926901
- add patch to fix missing includes
- rebuild for boost 1.81.0

* Thu Dec 22 2022 wally <wally> 1.14.6-2.mga9
+ Revision: 1925781
- rebuild for protobuf 21.12

* Mon Nov 21 2022 daviddavid <daviddavid> 1.14.6-1.mga9
+ Revision: 1909891
- new version: 1.14.6

* Sun Jul 03 2022 wally <wally> 1.14.3-8.mga9
+ Revision: 1867237
- rebuild for boost 1.79.0

* Sun Apr 03 2022 umeabot <umeabot> 1.14.3-7.mga9
+ Revision: 1842819
- Mageia 9 Mass Rebuild

* Tue Dec 28 2021 wally <wally> 1.14.3-6.mga9
+ Revision: 1764981
- rebuild for protobuf 3.19.1

* Sun Dec 19 2021 wally <wally> 1.14.3-5.mga9
+ Revision: 1762639
- rebuild for boost 1.78.0

* Sat Oct 02 2021 wally <wally> 1.14.3-4.mga9
+ Revision: 1748102
- rebuild for openssl 3.0.0

* Thu Sep 09 2021 wally <wally> 1.14.3-3.mga9
+ Revision: 1744688
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.14.3-2.mga9
+ Revision: 1722947
- rebuild for boost 1.76.0

* Fri Mar 05 2021 daviddavid <daviddavid> 1.14.3-1.mga9
+ Revision: 1698771
- new version: 1.14.3
- remove merged upstream patches

* Thu Dec 31 2020 wally <wally> 1.14.2-9.mga8
+ Revision: 1666745
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.14.2-8.mga8
+ Revision: 1661987
- rebuild for boost 1.74.0

* Fri Dec 18 2020 luigiwalser <luigiwalser> 1.14.2-7.mga8
+ Revision: 1660982
- rebuild for protobuf

* Wed Dec 16 2020 umeabot <umeabot> 1.14.2-6.mga8
+ Revision: 1658326
- Rebuild for new Qt5

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.14.2-5.mga8
+ Revision: 1650534
- rebuild for protobuf

* Sun Jun 28 2020 daviddavid <daviddavid> 1.14.2-4.mga8
+ Revision: 1600216
- add patch to fix build against Qt 5.15
- rebuild for new protobuf 3.12.3

* Sun May 03 2020 wally <wally> 1.14.2-3.mga8
+ Revision: 1578371
- add patch to fix build with boost 1.73
- rebuild for boost 1.73.0

* Thu Feb 20 2020 umeabot <umeabot> 1.14.2-2.mga8
+ Revision: 1545186
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 daviddavid <daviddavid> 1.14.2-1.mga8
+ Revision: 1484142
- new version: 1.14.2
- remove merged upstream patches
+ wally <wally>
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Thu Dec 19 2019 daviddavid <daviddavid> 1.10.0-12.mga8
+ Revision: 1468848
- rebuild for new protobuf 3.11.2

* Sat Mar 30 2019 umeabot <umeabot> 1.10.0-11.mga7
+ Revision: 1381538
- Qt5 Rebuild

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1.10.0-10.mga7
+ Revision: 1346013
- rebuild for protobuf

* Tue Oct 16 2018 wally <wally> 1.10.0-9.mga7
+ Revision: 1321022
- rebuild for new boost 1.68.0

* Fri Aug 24 2018 daviddavid <daviddavid> 1.10.0-8.mga7
+ Revision: 1253805
- rebuild for new miniupnpc 2.1

* Wed May 16 2018 daviddavid <daviddavid> 1.10.0-7.mga7
+ Revision: 1229921
- fix icon name in desktop file

* Wed May 16 2018 daviddavid <daviddavid> 1.10.0-6.mga7
+ Revision: 1229916
- port to Qt5
- split out devel and library files in their own subpkg
- add debian patch to rename libbitcoinconsensus to libdogecoinconsensus
- add debian patch to compile against openssl >= 1.1
- fix conflicting manpage files

* Sun Apr 15 2018 daviddavid <daviddavid> 1.10.0-5.mga7
+ Revision: 1219027
- rebuild for new protobuf 3.5

* Fri Mar 23 2018 daviddavid <daviddavid> 1.10.0-4.mga7
+ Revision: 1211523
- add archlinux patch to fix build with boost 1.66
+ wally <wally>
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 1.10.0-3.mga7
+ Revision: 1178095
- rebuild for boost 1.65

* Mon Oct 09 2017 daviddavid <daviddavid> 1.10.0-2.mga7
+ Revision: 1170353
- rebuild for new qrencode 4.0.0

* Sun Sep 24 2017 tv <tv> 1.10.0-1.mga7
+ Revision: 1158813
- new release
- drop merged patches
- build with compat-openssl10-devel
- rebuild with latest boost

* Tue May 16 2017 neoclust <neoclust> 1.8.3-8.mga6
+ Revision: 1102006
- Rebuild against new miniupnpc

* Tue Mar 15 2016 daviddavid <daviddavid> 1.8.3-7.mga6
+ Revision: 991022
- rediff fix-boost-get-usage patch (since fixed autopatch)

* Mon Mar 07 2016 daviddavid <daviddavid> 1.8.3-6.mga6
+ Revision: 986938
- rebuild against new openssl
- add missing BR on pkgconfig(openssl)

* Sat Dec 26 2015 daviddavid <daviddavid> 1.8.3-5.mga6
+ Revision: 915160
- rebuild for new boost 1.60.0

* Tue Oct 13 2015 fwang <fwang> 1.8.3-4.mga6
+ Revision: 890232
- deal with new api of miniupnpc4
- use configure2_5x
- rebuild for new miniupnpc

* Fri Sep 25 2015 daviddavid <daviddavid> 1.8.3-3.mga6
+ Revision: 883669
- rebuild for new boost 1.59.0

* Mon Aug 31 2015 cjw <cjw> 1.8.3-2.mga6
+ Revision: 871563
- rebuild with gcc 5

* Wed Aug 12 2015 blino <blino> 1.8.3-1.mga6
+ Revision: 864133
- use patch from bitcoin to fix boost::get usage (build broken with boost 1.58, dogecoin#1128)
- 1.8.3
+ daviddavid <daviddavid>
- rebuild for new boost-1.58.0

* Mon Jan 12 2015 buchan <buchan> 1.8.1-1.mga5
+ Revision: 810020
- Ship menus, man pages, bash completion etc.
- Fix BDB detection on cauldron
- Upgrade to 1.8.1, 1.4 no longer works

* Wed Dec 17 2014 sander85 <sander85> 1.4-5.mga5
+ Revision: 803792
- Rebuild for miniupnpc

* Wed Oct 15 2014 umeabot <umeabot> 1.4-4.mga5
+ Revision: 749451
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4-3.mga5
+ Revision: 678801
- Mageia 5 Mass Rebuild

* Wed May 14 2014 luigiwalser <luigiwalser> 1.4-2.mga5
+ Revision: 622817
- rebuild for miniupnpc

* Sun Jan 05 2014 blino <blino> 1.4-1.mga5
+ Revision: 564722
- 1.4
- initial Mageia package (1.3)
- Created package structure for dogecoin.

